@@ -5,28 +5,28 @@
 # The main function
 
 linear <- function(x, y, type = "linear", method = "none",
-	ws = -1, wax, way, wbx, wby, lowp = c(min(x[, 1]),
-	min(y[, 1])), midp = c(median(c(lowp[1], highp[1])),
-	median(c(lowp[2], highp[2]))), highp = c(max(x[, 1]),
-	max(y[, 1])), sx = highp[1] - lowp[1], sy = highp[2] -
+	ws = -1, wax, way, wbx, wby, lowp = c(min(scales(x)),
+	min(scales(y))), midp = c(median(c(lowp[1], highp[1])),
+	median(c(lowp[2], highp[2]))), highp = c(max(scales(x)),
+	max(scales(y))), sx = highp[1] - lowp[1], sy = highp[2] -
 	lowp[2], cx = midp[1], cy = midp[2], internal = TRUE,
 	lts = FALSE, verbose = FALSE, ...) {
 
 	if(missing(y))
-		y <- mfreqtab(x, 2)
-	if(ncol(y) < ncol(x))
-		x <- mfreqtab(x)
-	xscale <- unique(x[, 1])
+		y <- margin.table(x, 2)
+	if(margins(y) < margins(x))
+		x <- margin.table(x, 1)
+	xscale <- scales(x)
 	
 	if(method == "chained") {
 		if(type == "mean")
 			slope1 <- slope2 <- 1
 		else {
-			slope1 <- sd.freqtab(y[, -2])/sd.freqtab(y[, -1])
-			slope2 <- sd.freqtab(x[, -1])/sd.freqtab(x[, -2])
+			slope1 <- sd.freqtab(y)/sd.freqtab(y, 2)
+			slope2 <- sd.freqtab(x, 2)/sd.freqtab(x)
 		}
-		intercept <- slope1*(mean.freqtab(x[, -1]) -
-			slope2*mean(x) - mean.freqtab(y[, -1])) + mean(y)
+		intercept <- slope1 * (mean(x, 2) -
+			slope2 * mean(x) - mean(y, 2)) + mean(y)
 		slope <- slope1*slope2
 	}
 	else {
@@ -49,8 +49,8 @@ linear <- function(x, y, type = "linear", method = "none",
 				sigmax <- synth$gamma[1]
 				sigmay <- synth$gamma[2]
 				mux <- mean(x)
-				muy <- mean(y) + synth$gamma[2]*(mean.freqtab(x[, -1]) -
-					mean.freqtab(y[, -1]))
+				muy <- mean(y) + synth$gamma[2] *
+					(mean(x, 2) - mean(y, 2))
 			}
 		}
 		if(type %in% c("identity", "general linear")) {
@@ -71,10 +71,10 @@ linear <- function(x, y, type = "linear", method = "none",
 			if(missing(wbx)) wbx <- 1
 			if(missing(wby)) wby <- 1
 		}
-		if(is.function(cx)) cx <- cx(x, y, ...)
-		if(is.function(cy)) cy <- cy(x, y, ...)
-		if(is.function(sx)) sx <- sx(x, y, ...)
-		if(is.function(sy)) sy <- sy(x, y, ...)
+		if(cx == "cy") cx <- muy
+		if(cy == "cx") cy <- mux
+		if(sx == "sy") sx <- sigmay
+		if(sy == "sx") sy <- sigmax
 		# Put sigma on the scale of s
 		# sigmayr <- sigmay*sx/sigmax
 		# Then, sigmaxr <- sx
