@@ -1,38 +1,36 @@
 ### R code from vignette source 'equatevignette.Rnw'
 
 ###################################################
-### code chunk number 1: equatevignette.Rnw:334-335
+### code chunk number 1: equatevignette.Rnw:372-374
 ###################################################
-options(prompt="R>")
+op <- options()
+options(prompt = "R>", show.signif.stars = FALSE, warn = -1)
 
 
 ###################################################
-### code chunk number 2: equatevignette.Rnw:337-341
+### code chunk number 2: equatevignette.Rnw:376-379
 ###################################################
 library("equate")
-act.x <- as.freqtab(cbind(ACTmath[, 1], ACTmath[, 2]))
-act.y <- as.freqtab(cbind(ACTmath[, 1], ACTmath[, 3]))
-act.x[1:4,]
+act.x <- as.freqtab(ACTmath[, 1:2])
+act.y <- as.freqtab(ACTmath[, c(1, 3)])
 
 
 ###################################################
-### code chunk number 3: equatevignette.Rnw:344-345
+### code chunk number 3: equatevignette.Rnw:382-384
 ###################################################
+head(act.x)
 rbind(x = summary(act.x), y = summary(act.y))
 
 
 ###################################################
-### code chunk number 4: equatevignette.Rnw:348-353
+### code chunk number 4: equatevignette.Rnw:387-389
 ###################################################
-neat.x <- freqtab(KBneat$x[, 1], KBneat$x[, 2],
-	xscale = 0:36, vscale = 0:12)
-neat.y <- freqtab(KBneat$y[, 1], KBneat$y[, 2],
-	xscale = 0:36, vscale = 0:12)
-neat.x[50:55, ]
+neat.x <- freqtab(KBneat$x, scales = list(0:36, 0:12))
+neat.y <- freqtab(KBneat$y, scales = list(0:36, 0:12))
 
 
 ###################################################
-### code chunk number 5: equatevignette.Rnw:358-369
+### code chunk number 5: equatevignette.Rnw:393-403
 ###################################################
 attach(PISA)
 r3items <- paste(items$itemid[items$clusterid == "r3a"])
@@ -40,15 +38,14 @@ r6items <- paste(items$itemid[items$clusterid == "r6"])
 r5items <- paste(items$itemid[items$clusterid == "r5"])
 r7items <- paste(items$itemid[items$clusterid == "r7"])
 pisa <- freqtab(students[students$book == 6, ],
-	xitems = c(r3items, r6items),
-	vitems = c(r5items, r7items),
-	xscale = 0:31, vscale = 0:29)
+	items = list(c(r3items, r6items), c(r5items, r7items)),
+	scales = list(0:31, 0:29))
 round(data.frame(summary(pisa),
 	row.names = c("r3r6", "r5r7")), 2)
 
 
 ###################################################
-### code chunk number 6: equatevignette.Rnw:373-375
+### code chunk number 6: equatevignette.Rnw:407-409
 ###################################################
 plot(x = act.x, lwd = 2, xlab = "Score", ylab = "Count")
 plot(neat.x)
@@ -67,88 +64,107 @@ plot(neat.x)
 
 
 ###################################################
-### code chunk number 9: equatevignette.Rnw:385-386
+### code chunk number 9: equatevignette.Rnw:419-420
 ###################################################
 plot(x = act.x, lwd = 2, xlab = "Score", ylab = "Count")
 
 
 ###################################################
-### code chunk number 10: equatevignette.Rnw:395-396
+### code chunk number 10: equatevignette.Rnw:429-430
 ###################################################
 plot(neat.x)
 
 
 ###################################################
-### code chunk number 11: equatevignette.Rnw:406-413
+### code chunk number 11: equatevignette.Rnw:441-443 (eval = FALSE)
 ###################################################
-neat.xs <- presmoothing(neat.x, smooth = "log", degree = 3,
-	xdegree = 1, asfreqtab = TRUE)
-rbind(x = summary(neat.x), xs = summary(neat.xs))
-neat.xsmat <- presmoothing(neat.x, "log",
-	degree = 3, xdegree = 1, stepup = TRUE)
+## presmoothing(~ poly(total, 3, raw = T) + poly(anchor, 3, raw = T) +
+## 	total:anchor, data = neat.x)
+
+
+###################################################
+### code chunk number 12: equatevignette.Rnw:448-451 (eval = FALSE)
+###################################################
+## neat.xsf <- with(as.data.frame(neat.x), cbind(total, total^2,
+## 	total^3, anchor, anchor^2, anchor^3, total*anchor))
+## presmoothing(neat.x, smooth = "loglinear", scorefun = neat.xsf)
+
+
+###################################################
+### code chunk number 13: equatevignette.Rnw:456-457
+###################################################
+neat.xs <- presmoothing(neat.x, smooth = "log", degrees = list(3, 1))
+
+
+###################################################
+### code chunk number 14: equatevignette.Rnw:462-467
+###################################################
+neat.xsmat <- presmoothing(neat.x, smooth = "loglinear",
+	degrees = list(3, 1), stepup = TRUE)
 plot(neat.xs)
-plot(neat.x, neat.xsmat[, c(2:3, 5:7)], ycol = 1, ylty = 1:5)
+plot(neat.x, neat.xsmat, ylty = 1:4)
+round(rbind(x = summary(neat.x), xs = summary(neat.xs)), 2)
 
 
 ###################################################
-### code chunk number 12: plotbivarsmooth1
+### code chunk number 15: plotbivarsmooth1
 ###################################################
 plot(neat.xs)
 
 
 ###################################################
-### code chunk number 13: plotbivarsmooth2
+### code chunk number 16: plotbivarsmooth2
 ###################################################
-plot(neat.x, neat.xsmat[, c(2:3, 5:7)], ycol = 1, ylty = 1:5)
+plot(neat.x, neat.xsmat, ylty = 1:5)
 
 
 ###################################################
-### code chunk number 14: equatevignette.Rnw:423-424
+### code chunk number 17: equatevignette.Rnw:477-478
 ###################################################
 plot(neat.xs)
 
 
 ###################################################
-### code chunk number 15: equatevignette.Rnw:433-434
+### code chunk number 18: equatevignette.Rnw:487-488
 ###################################################
-plot(neat.x, neat.xsmat[, c(2:3, 5:7)], ycol = 1, ylty = 1:5)
+plot(neat.x, neat.xsmat, ylty = 1:5)
 
 
 ###################################################
-### code chunk number 16: equatevignette.Rnw:442-444
+### code chunk number 19: equatevignette.Rnw:498-500
 ###################################################
-presmoothing(neat.x, "log", degree = 3,
-	xdegree = 1, compare = TRUE)
+presmoothing(neat.x, smooth = "loglinear",
+	degrees = list(c(3, 3), c(1, 1)), compare = TRUE)
 
 
 ###################################################
-### code chunk number 17: equatevignette.Rnw:449-450
+### code chunk number 20: equatevignette.Rnw:505-506
 ###################################################
 equate(act.x, act.y, type = "mean")
 
 
 ###################################################
-### code chunk number 18: equatevignette.Rnw:453-455
+### code chunk number 21: equatevignette.Rnw:509-511
 ###################################################
 neat.ef <- equate(neat.x, neat.y, type = "equip",
 	method = "frequency estimation", smoothmethod = "log")
 
 
 ###################################################
-### code chunk number 19: equatevignette.Rnw:460-461
+### code chunk number 22: equatevignette.Rnw:516-517
 ###################################################
 summary(neat.ef)
 
 
 ###################################################
-### code chunk number 20: equatevignette.Rnw:465-467
+### code chunk number 23: equatevignette.Rnw:521-523
 ###################################################
 cbind(newx = c(3, 29, 8, 7, 13),
 	yx = equate(c(3, 29, 8, 7, 13), y = neat.ef))
 
 
 ###################################################
-### code chunk number 21: equatevignette.Rnw:472-478
+### code chunk number 24: equatevignette.Rnw:528-534
 ###################################################
 neat.i <- equate(neat.x, neat.y, type = "ident")
 neat.lt <- equate(neat.x, neat.y, type = "linear",
@@ -159,19 +175,19 @@ plot(neat.comp, addident = FALSE)
 
 
 ###################################################
-### code chunk number 22: plotcomposite
+### code chunk number 25: plotcomposite
 ###################################################
 plot(neat.comp, addident = FALSE)
 
 
 ###################################################
-### code chunk number 23: equatevignette.Rnw:487-488
+### code chunk number 26: equatevignette.Rnw:543-544
 ###################################################
 plot(neat.comp, addident = FALSE)
 
 
 ###################################################
-### code chunk number 24: equatevignette.Rnw:501-509
+### code chunk number 27: equatevignette.Rnw:557-565
 ###################################################
 pisa.i <- equate(pisa, type = "ident", lowp = c(3.5, 2))
 pisa.m <- equate(pisa, type = "mean", lowp = c(3.5, 2))
@@ -184,60 +200,105 @@ plot(pisa.i, pisa.m, pisa.l, pisa.c, pisa.e, addident = F,
 
 
 ###################################################
-### code chunk number 25: plotstudy2
+### code chunk number 28: plotstudy2
 ###################################################
 plot(pisa.i, pisa.m, pisa.l, pisa.c, pisa.e, addident = F,
 	xpoints = pisa, morepars = list(ylim = c(0, 31)))
 
 
 ###################################################
-### code chunk number 26: equatevignette.Rnw:517-518
+### code chunk number 29: equatevignette.Rnw:573-574
 ###################################################
 plot(pisa.i, pisa.m, pisa.l, pisa.c, pisa.e, addident = F,
 	xpoints = pisa, morepars = list(ylim = c(0, 31)))
 
 
 ###################################################
-### code chunk number 27: equatevignette.Rnw:535-545
+### code chunk number 30: equatevignette.Rnw:585-589
 ###################################################
-neat.xp <- presmoothing(neat.x, "log", xdegree = 2,
-	asfreqtab = TRUE)
-neat.xpmat <- presmoothing(neat.x, "log", xdegree = 2,
+pisa.x <- freqtab(totals$b4[1:200, c("r3a", "r2", "s2")],
+	scales = list(0:15, 0:17, 0:18))
+pisa.y <- freqtab(totals$b4[201:400, c("r4a", "r2", "s2")],
+	scales = list(0:16, 0:17, 0:18))
+
+
+###################################################
+### code chunk number 31: equatevignette.Rnw:594-600
+###################################################
+pisa.mnom <- equate(pisa.x, pisa.y, type = "mean",
+	method = "nom")
+pisa.mtuck <- equate(pisa.x, pisa.y, type = "linear",
+	method = "tuck")
+pisa.mfreq <- equate(pisa.x, pisa.y, type = "equip",
+	method = "freq", smooth = "loglin")
+
+
+###################################################
+### code chunk number 32: equatevignette.Rnw:603-609
+###################################################
+pisa.snom <- equate(margin(pisa.x, 1:2), margin(pisa.y, 1:2),
+	type = "mean", method = "nom")
+pisa.stuck <- equate(margin(pisa.x, 1:2), margin(pisa.y, 1:2),
+	type = "linear", method = "tuck")
+pisa.sfreq <- equate(margin(pisa.x, 1:2), margin(pisa.y, 1:2),
+	type = "equip", method = "freq", smooth = "loglin")
+
+
+###################################################
+### code chunk number 33: plotstudy3
+###################################################
+plot(pisa.snom, pisa.stuck, pisa.sfreq,
+	pisa.mnom, pisa.mtuck, pisa.mfreq,
+	col = rep(rainbow(3), 2), lty = rep(1:2, each = 3))
+
+
+###################################################
+### code chunk number 34: equatevignette.Rnw:619-620
+###################################################
+plot(pisa.snom, pisa.stuck, pisa.sfreq,
+	pisa.mnom, pisa.mtuck, pisa.mfreq,
+	col = rep(rainbow(3), 2), lty = rep(1:2, each = 3))
+
+
+###################################################
+### code chunk number 35: equatevignette.Rnw:635-643
+###################################################
+neat.xp <- presmoothing(neat.x, "loglinear", degrees = list(4, 2))
+neat.xpmat <- presmoothing(neat.x, "loglinear", degrees = list(4, 2),
 	stepup = TRUE)
-neat.yp <- presmoothing(neat.y, "log", xdegree = 2,
-	asfreqtab = TRUE)
-neat.ypmat <- presmoothing(neat.y, "log", xdegree = 2,
+neat.yp <- presmoothing(neat.y, "loglinear", degrees = list(4, 2))
+neat.ypmat <- presmoothing(neat.y, "loglinear", degrees = list(4, 2),
 	stepup = TRUE)
-plot(neat.x, neat.xpmat[, c(3, 4, 7:10)])
-plot(neat.y, neat.ypmat[, c(3, 4, 7:10)])
+plot(neat.x, neat.xpmat)
+plot(neat.y, neat.ypmat)
 
 
 ###################################################
-### code chunk number 28: plotstudy1x
+### code chunk number 36: plotstudy1x
 ###################################################
-plot(neat.x, neat.xpmat[, c(3, 4, 7:10)])
+plot(neat.x, neat.xpmat)
 
 
 ###################################################
-### code chunk number 29: plotstudy1y
+### code chunk number 37: plotstudy1y
 ###################################################
-plot(neat.y, neat.ypmat[, c(3, 4, 7:10)])
+plot(neat.y, neat.ypmat)
 
 
 ###################################################
-### code chunk number 30: equatevignette.Rnw:556-557
+### code chunk number 38: equatevignette.Rnw:654-655
 ###################################################
-plot(neat.x, neat.xpmat[, c(3, 4, 7:10)])
+plot(neat.x, neat.xpmat)
 
 
 ###################################################
-### code chunk number 31: equatevignette.Rnw:566-567
+### code chunk number 39: equatevignette.Rnw:664-665
 ###################################################
-plot(neat.y, neat.ypmat[, c(3, 4, 7:10)])
+plot(neat.y, neat.ypmat)
 
 
 ###################################################
-### code chunk number 32: equatevignette.Rnw:575-580
+### code chunk number 40: equatevignette.Rnw:673-678
 ###################################################
 set.seed(131031)
 reps <- 100
@@ -247,7 +308,7 @@ crit <- equate(neat.xp, neat.yp, "e", "c")$conc$yx
 
 
 ###################################################
-### code chunk number 33: equatevignette.Rnw:583-594
+### code chunk number 41: equatevignette.Rnw:681-692
 ###################################################
 neat.args <- list(i = list(type = "i"),
 	mt = list(type = "mean", method = "t"),
@@ -263,80 +324,80 @@ bootout <- bootstrap(x = neat.xp, y = neat.yp, xn = xn, yn = yn,
 
 
 ###################################################
-### code chunk number 34: equatevignette.Rnw:597-606
+### code chunk number 42: equatevignette.Rnw:695-702
 ###################################################
 plot(bootout, addident = F, col = c(1, rainbow(8)))
 plot(bootout, out = "se", addident = F,
 	col = c(1, rainbow(8)), legendplace = "top")
-plot(bootout, out = "bias", addident = F,
-	col = c(1, rainbow(8)), legendplace = "top",
-	morepars = list(ylim = c(-.9, 3)))
-plot(bootout, out = "rmse", addident = F,
-	col = c(1, rainbow(8)), legendplace = "top",
-	morepars = list(ylim = c(0, 3)))
+plot(bootout, out = "bias", addident = F, legendplace = "top",
+	col = c(1, rainbow(8)), morepars = list(ylim = c(-.9, 3)))
+plot(bootout, out = "rmse", addident = F, legendplace = "top",
+	col = c(1, rainbow(8)), morepars = list(ylim = c(0, 3)))
 
 
 ###################################################
-### code chunk number 35: plotstudy1means
+### code chunk number 43: plotstudy1means
 ###################################################
 plot(bootout, addident = F, col = c(1, rainbow(8)))
 
 
 ###################################################
-### code chunk number 36: plotstudy1se
+### code chunk number 44: plotstudy1se
 ###################################################
 plot(bootout, out = "se", addident = F,
 	col = c(1, rainbow(8)), legendplace = "top")
 
 
 ###################################################
-### code chunk number 37: plotstudy1bias
+### code chunk number 45: plotstudy1bias
 ###################################################
-plot(bootout, out = "bias", addident = F,
-	col = c(1, rainbow(8)), legendplace = "top",
-	morepars = list(ylim = c(-.9, 3)))
+plot(bootout, out = "bias", addident = F, legendplace = "top",
+	col = c(1, rainbow(8)), morepars = list(ylim = c(-.9, 3)))
 
 
 ###################################################
-### code chunk number 38: plotstudy1rmse
+### code chunk number 46: plotstudy1rmse
 ###################################################
-plot(bootout, out = "rmse", addident = F,
-	col = c(1, rainbow(8)), legendplace = "top",
-	morepars = list(ylim = c(0, 3)))
+plot(bootout, out = "rmse", addident = F, legendplace = "top",
+	col = c(1, rainbow(8)), morepars = list(ylim = c(0, 3)))
 
 
 ###################################################
-### code chunk number 39: equatevignette.Rnw:627-628
+### code chunk number 47: equatevignette.Rnw:721-722
 ###################################################
 plot(bootout, addident = F, col = c(1, rainbow(8)))
 
 
 ###################################################
-### code chunk number 40: equatevignette.Rnw:637-638
+### code chunk number 48: equatevignette.Rnw:731-732
 ###################################################
 plot(bootout, out = "se", addident = F,
 	col = c(1, rainbow(8)), legendplace = "top")
 
 
 ###################################################
-### code chunk number 41: equatevignette.Rnw:647-648
+### code chunk number 49: equatevignette.Rnw:741-742
 ###################################################
-plot(bootout, out = "bias", addident = F,
-	col = c(1, rainbow(8)), legendplace = "top",
-	morepars = list(ylim = c(-.9, 3)))
+plot(bootout, out = "bias", addident = F, legendplace = "top",
+	col = c(1, rainbow(8)), morepars = list(ylim = c(-.9, 3)))
 
 
 ###################################################
-### code chunk number 42: equatevignette.Rnw:657-658
+### code chunk number 50: equatevignette.Rnw:751-752
 ###################################################
-plot(bootout, out = "rmse", addident = F,
-	col = c(1, rainbow(8)), legendplace = "top",
-	morepars = list(ylim = c(0, 3)))
+plot(bootout, out = "rmse", addident = F, legendplace = "top",
+	col = c(1, rainbow(8)), morepars = list(ylim = c(0, 3)))
 
 
 ###################################################
-### code chunk number 43: equatevignette.Rnw:666-667
+### code chunk number 51: equatevignette.Rnw:760-761
 ###################################################
 round(summary(bootout), 2)
 
 
+###################################################
+### code chunk number 52: equatevignette.Rnw:763-764
+###################################################
+options(op)
+
+
